@@ -298,13 +298,13 @@
             }
         }
 
-        $(MediaController).on('playbackstop', onPlaybackStop);
+        Events.on(MediaController, 'playbackstop', onPlaybackStop);
     });
 
     pageIdOn('pagebeforehide', "tvRecommendedPage", function () {
 
         var page = this;
-        $(MediaController).off('playbackstop', onPlaybackStop);
+        Events.off(MediaController, 'playbackstop', onPlaybackStop);
     });
 
     function onPlaybackStop(e, state) {
